Module app

Module app 

Modules

message

Structs

App
Root UI state: reduces terminal input and ACP events into the canonical conversation, feature state, and composer that the renderer draws each frame.
AppConfig

Enums

ExitState
ForegroundOperation
Overlay
The transient destination above the active route. Only one overlay receives normal input at a time.
PromptPhase
Route
The full-screen destinations in the application.