pub struct AppConfig {
pub width: u32,
pub height: u32,
pub power_preference: PowerPreference,
}Expand description
Runtime configuration passed to Application::new.
Fields
width: u32Logical width of the stage in pixels at DPR 1×.
height: u32Logical height of the stage in pixels at DPR 1×.
power_preference: PowerPreferenceGPU power preference. Defaults to HighPerformance.