ElicitationForm

Struct ElicitationForm 

pub struct ElicitationForm {
    pub ui: ElicitationUi,
    /* private fields */
}

Fields

ui: ElicitationUi

Implementations

Source

impl ElicitationForm

pub fn from_params( params: ElicitationParams, responder: Responder<ElicitationResponse>, ) -> Self

pub fn with_browser_opener<T>( params: ElicitationParams, responder: Responder<ElicitationResponse>, browser_opener: T, ) -> Self
where T: Fn(&str) -> Result<(), String> + Send + Sync + 'static,

pub fn with_url_handlers<T, U>( params: ElicitationParams, responder: Responder<ElicitationResponse>, browser_opener: T, clipboard_writer: U, ) -> Self
where T: Fn(&str) -> Result<(), String> + Send + Sync + 'static, U: Fn(&str) -> Result<(), String> + Send + Sync + 'static,

pub fn confirm(&self) -> ElicitationResponse

pub fn cancel() -> ElicitationResponse

pub fn cancel_pending(&mut self)

Send Cancel to the responder if one is still attached. Used when the owning container is displacing this form before the user responded.

pub fn accept_url_complete( &mut self, params: &UrlElicitationCompleteParams, ) -> bool

If this form is showing the URL prompt that params refers to, accept it and consume the responder. Returns true iff the form was answered.