pub struct Conversation { /* private fields */ }Implementations
Sourceimpl Conversation
impl Conversation
pub fn new() -> Self
pub fn id(&self) -> ConversationId
pub fn items(&self) -> &[ConversationItem]
pub fn append_user_content( &mut self, text: impl Into<String>, ) -> ConversationItemId
Sourcepub fn append_pending_user_content(
&mut self,
text: impl Into<String>,
) -> ConversationItemId
pub fn append_pending_user_content( &mut self, text: impl Into<String>, ) -> ConversationItemId
Echo a submitted prompt before the agent acknowledges it; the next
user_message upsert adopts this item instead of appending another.
pub fn upsert_message( &mut self, role: MessageRole, message_id: MessageId, content: &MaybeUndefined<Vec<ContentBlock>>, )
pub fn append_message_chunk(&mut self, role: MessageRole, chunk: &ContentChunk)
pub fn append_notice(&mut self, text: impl Into<String>) -> ConversationItemId
pub fn on_tool_call_update(&mut self, update: &ToolCallUpdate)
pub fn on_tool_call_content_chunk(&mut self, chunk: &ToolCallContentChunk)
pub fn on_sub_agent_progress(&mut self, notification: &SubAgentProgressParams)
pub fn finish_turn(&mut self, terminal_status: &ToolStatus)
pub fn clear(&mut self)
pub fn turn(&self) -> &TurnState
pub fn turn_mut(&mut self) -> &mut TurnState
pub fn plan_tracker(&self) -> &PlanTracker
pub fn plan_tracker_mut(&mut self) -> &mut PlanTracker
pub fn progress_indicator(&self) -> &ProgressIndicator
pub fn progress_indicator_mut(&mut self) -> &mut ProgressIndicator
pub fn reset_feature_state(&mut self)
pub fn any_running(&self) -> bool