pub enum GitWatchError {
Git(GitError),
FileWatch(FileWatchError),
Stopped,
}Expand description
A failure while starting, watching, or loading for a crate::RepositoryWatcher.
Variants
Git(GitError)
FileWatch(FileWatchError)
The platform watcher could not be created or could not observe a path.
Stopped
The watcher task is no longer running.