pub struct FakeExecutor { /* private fields */ }Expand description
A deterministic command runner for integration tests.
Commands are recorded in submission order. Tests may enqueue completions for commands whose results are part of the scenario; commands without a queued completion are still recorded and produce no state change.
Implementations
Sourceimpl FakeExecutor
impl FakeExecutor
pub fn new() -> Self
pub fn with_git(git: FakeGit) -> Self
pub fn git(&self) -> &FakeGit
pub fn git_mut(&mut self) -> &mut FakeGit
pub fn git_watch_id(&self) -> Option<RequestId>
pub fn next_git_watch_event(&mut self) -> Option<GitWatchEvent>
pub fn filesystem(&self) -> &FakeFilesystem
pub fn filesystem_mut(&mut self) -> &mut FakeFilesystem
pub fn record(&mut self, commands: impl IntoIterator<Item = Command>)
pub fn take_commands(&mut self) -> Vec<Command>