Module selection

Module selection 

Structs

SelectionState
Cursor and scroll offset for a list of len items.

Enums

Direction

Functions

scroll_into_view
offset moved the least it can to bring row inside a viewport height rows tall.
step_clamped
Shifts value by amount rows in direction, stopping at zero and max.