pub struct CodeBlockState { /* private fields */ }Expand description
Where highlighting of a code block got to — enough to continue it later with byte-identical output, so a streaming block can highlight only its new lines instead of the whole block again.