pub struct DiffDocument {
pub repo_root: PathBuf,
pub files: Vec<FileDiff>,
}Fields
repo_root: PathBuffiles: Vec<FileDiff>Implementations
Sourceimpl DiffDocument
impl DiffDocument
Sourcepub fn from_git_output(
repo_root: PathBuf,
diff_output: &str,
status_output: &str,
untracked_files: impl IntoIterator<Item = (String, Vec<u8>)>,
scope: DiffScope,
) -> Result<Self, GitDiffError>
pub fn from_git_output( repo_root: PathBuf, diff_output: &str, status_output: &str, untracked_files: impl IntoIterator<Item = (String, Vec<u8>)>, scope: DiffScope, ) -> Result<Self, GitDiffError>
Normalizes command output into the model consumed by both review renderers.
Git execution deliberately happens outside this type. Keeping this operation synchronous makes parsing deterministic and lets tests exercise it without a repository or subprocess.