#[non_exhaustive]pub enum PathCommand {
MoveTo(Vec2),
LineTo(Vec2),
QuadTo {
control: Vec2,
end: Vec2,
},
CubicTo {
c1: Vec2,
c2: Vec2,
end: Vec2,
},
Close,
}Expand description
One command in a path. The path is a sequence of these; rendering / flattening walks them in order.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MoveTo(Vec2)
Lift the pen and move to p. Starts a new subpath.
LineTo(Vec2)
Draw a straight line from the current point to p.
QuadTo
Quadratic Bezier from current point through control to
end.
CubicTo
Cubic Bezier from current point through c1 and c2 to
end.
Close
Close the current subpath with a line back to its MoveTo.